@@ -6,7 +6,7 @@ package Map::Metro::Graph;
 
 # ABSTRACT: An entire graph
 our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
-our $VERSION = '0.2403';
+our $VERSION = '0.2404';
 
 use if $] >= 5.016000, feature => 'fc';
 
@@ -730,6 +730,16 @@ sub all_pairs {
     return $routings;
 }
 
+sub to_hash {
+    my $self = shift;
+
+    return {
+        routings => [
+            map { $_->to_hash } $self->all_routings
+        ],
+    }
+}
+
 1;
 
 __END__
@@ -744,7 +754,7 @@ Map::Metro::Graph - An entire graph
 
 =head1 VERSION
 
-Version 0.2403, released 2016-03-19.
+Version 0.2404, released 2016-04-30.
 
 
 
