@@ -6,11 +6,12 @@ package Map::Metro::Graph::Connection;
 
 # ABSTRACT: Connects two stations on a line
 our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
-our $VERSION = '0.2403';
+our $VERSION = '0.2404';
 
 use Map::Metro::Elk;
 use Types::Standard qw/Maybe Int/;
 use Map::Metro::Types qw/LineStation Connection/;
+use PerlX::Maybe qw/maybe/;
 
 has origin_line_station => (
     is => 'ro',
@@ -39,6 +40,18 @@ has weight => (
     default => 1,
 );
 
+sub to_hash {
+    my $self = shift;
+
+    return {
+              origin_line_station => $self->origin_line_station->to_hash,
+              destination_line_station => $self->destination_line_station->to_hash,
+        maybe previous_connection => $self->has_previous_connection ? $self->previous_connection->to_hash : undef,
+        maybe next_connection => $self->has_next_connection ? $self->next_connection->to_hash : undef,
+              weight => $self->weight,
+    };
+}
+
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -55,7 +68,7 @@ Map::Metro::Graph::Connection - Connects two stations on a line
 
 =head1 VERSION
 
-Version 0.2403, released 2016-03-19.
+Version 0.2404, released 2016-04-30.
 
 =head1 DESCRIPTION
 
