@@ -6,7 +6,7 @@ package Map::Metro::Graph::Line;
 
 # ABSTRACT: Meta information about a line
 our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
-our $VERSION = '0.2403';
+our $VERSION = '0.2404';
 
 use Map::Metro::Elk;
 use Types::Standard qw/Str Int/;
@@ -49,6 +49,18 @@ around BUILDARGS => sub {
     $self->$orig(%args);
 };
 
+sub to_hash {
+    my $self = shift;
+
+    return {
+        id => $self->id,
+        name => $self->name,
+        description => $self->description,
+        color => $self->color,
+        width => $self->width,
+    }
+}
+
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -65,7 +77,7 @@ Map::Metro::Graph::Line - Meta information about a line
 
 =head1 VERSION
 
-Version 0.2403, released 2016-03-19.
+Version 0.2404, released 2016-04-30.
 
 =head1 DESCRIPTION
 
