@@ -6,7 +6,7 @@ package Map::Metro::Graph::LineStation;
 
 # ABSTRACT: A station on a specific line
 our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
-our $VERSION = '0.2403';
+our $VERSION = '0.2404';
 
 use Map::Metro::Elk;
 use Types::Standard qw/Int/;
@@ -47,6 +47,16 @@ sub on_same_line {
     return $self->line->id eq $other->line->id;
 }
 
+sub to_hash {
+    my $self = shift;
+
+    return {
+        line_station_id => $self->line_station_id,
+        station => $self->station->to_hash,
+        line => $self->line->to_hash,
+    };
+}
+
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -63,7 +73,7 @@ Map::Metro::Graph::LineStation - A station on a specific line
 
 =head1 VERSION
 
-Version 0.2403, released 2016-03-19.
+Version 0.2404, released 2016-04-30.
 
 =head1 DESCRIPTION
 
