@@ -6,7 +6,7 @@ package Map::Metro::Graph::Route;
 
 # ABSTRACT: A sequence of line stations
 our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
-our $VERSION = '0.2403';
+our $VERSION = '0.2404';
 
 use Map::Metro::Elk;
 use Types::Standard qw/ArrayRef Str/;
@@ -72,6 +72,20 @@ sub longest_line_name_length {
     return length((sort { length $b->origin_line_station->line->name <=> length $a->origin_line_station->line->name } $self->all_steps)[0]->origin_line_station->line->name);
 }
 
+sub to_hash {
+    my $self = shift;
+
+    return {
+        id => $self->id,
+        steps => [
+            map { $_->to_hash } $self->all_steps,
+        ],
+        line_stations => [
+            map { $_->to_hash } $self->all_line_stations,
+        ],
+    };
+}
+
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -88,7 +102,7 @@ Map::Metro::Graph::Route - A sequence of line stations
 
 =head1 VERSION
 
-Version 0.2403, released 2016-03-19.
+Version 0.2404, released 2016-04-30.
 
 =head1 DESCRIPTION
 
