@@ -6,7 +6,7 @@ package Map::Metro::Graph::Routing;
 
 # ABSTRACT: A collection of routes between two stations
 our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
-our $VERSION = '0.2403';
+our $VERSION = '0.2404';
 
 use Map::Metro::Elk;
 use Types::Standard qw/ArrayRef/;
@@ -63,6 +63,21 @@ sub ordered_routes {
     $self->sort_routes(sub { $_[0]->weight <=> $_[1]->weight });
 }
 
+sub to_hash {
+    my $self = shift;
+
+    return {
+        origin_station => $self->origin_station->to_hash,
+        destination_station => $self->destination_station->to_hash,
+        line_stations => [
+            map { $_->to_hash } $self->all_line_stations,
+        ],
+        routes => [
+            map { $_->to_hash } $self->all_routes,
+        ],
+    };
+}
+
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -79,7 +94,7 @@ Map::Metro::Graph::Routing - A collection of routes between two stations
 
 =head1 VERSION
 
-Version 0.2403, released 2016-03-19.
+Version 0.2404, released 2016-04-30.
 
 =head1 DESCRIPTION
 
