@@ -6,7 +6,7 @@ package Map::Metro::Graph::Station;
 
 # ABSTRACT: Information about a station
 our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
-our $VERSION = '0.2403';
+our $VERSION = '0.2404';
 
 use Map::Metro::Elk;
 use Types::Standard qw/Int Str Maybe ArrayRef Bool/;
@@ -193,6 +193,25 @@ sub undiacriticise {
     return;
 }
 
+sub to_hash {
+    my $self = shift;
+
+    return {
+        id => $self->id,
+        name => $self->name,
+        original_name => $self->original_name,
+        search_names => [ $self->all_search_names ],
+        alternative_names => [ $self->all_alternative_names ],
+        lines => [
+            map { $_->to_hash } $self->all_lines
+        ],
+       # connecting_stations => [
+       #     map { $_->to_hash } $self->all_connecting_stations
+       # ],
+
+    }
+}
+
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -209,7 +228,7 @@ Map::Metro::Graph::Station - Information about a station
 
 =head1 VERSION
 
-Version 0.2403, released 2016-03-19.
+Version 0.2404, released 2016-04-30.
 
 
 
