@@ -6,11 +6,12 @@ package Map::Metro::Graph::Step;
 
 # ABSTRACT: The movement from one station to the next in a route
 our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
-our $VERSION = '0.2403';
+our $VERSION = '0.2404';
 
 use Map::Metro::Elk;
 use Types::Standard qw/Maybe Int/;
 use Map::Metro::Types qw/LineStation Step/;
+use PerlX::Maybe qw/maybe/;
 
 has origin_line_station => (
     is => 'ro',
@@ -85,6 +86,18 @@ sub was_station_transfer {
     return $self->previous_step->is_station_transfer;
 }
 
+sub to_hash {
+    my $self = shift;
+
+    return {
+              origin_line_station => $self->origin_line_station->to_hash,
+              destination_line_station => $self->destination_line_station->to_hash,
+       # maybe previous_step => $self->has_previous_step ? $self->previous_step->to_hash : undef,
+       # maybe next_step => $self->has_next_step ? $self->next_step->to_hash : undef,
+              weight => $self->weight,
+    };
+}
+
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -101,7 +114,7 @@ Map::Metro::Graph::Step - The movement from one station to the next in a route
 
 =head1 VERSION
 
-Version 0.2403, released 2016-03-19.
+Version 0.2404, released 2016-04-30.
 
 =head1 DESCRIPTION
 
